<?php

namespace pachno\modules\livelink_github;

use pachno\core\framework,
    Github\Client as GithubClient,
    pachno\core\entities\User,
    pachno\core\modules\livelink\BaseConnector;

class Connector extends BaseConnector
{

    public function getName()
    {
        return "GitHub";
    }

    public function getLogo()
    {
        return "github";
    }

    public function getLogoStyle()
    {
        return "fab";
    }

    public function getProjectTemplateDescription()
    {
        return $this->getI18n()->__('Import / link a project from GitHub');
    }

    public function doesSupportImportIssues()
    {
        return true;
    }

    public function doesSupportLinkIssues()
    {
        return true;
    }

    /**
     * @return GithubClient
     */
    public function getGithubClient()
    {
        $token = $this->getUserToken();
        $client = new GithubClient();
        $client->authenticate($token, null, GithubClient::AUTH_HTTP_TOKEN);

        return $client;
    }

    public function isConfigured()
    {
        return $this->getUserToken() != '';
    }

    public function getUserToken(User $user = null)
    {
        $user_id = ($user instanceof User) ? $user->getID() : framework\Context::getUser()->getID();
        return framework\Settings::getUserSetting($user_id, 'github_token', Livelink_github::getModule()->getName());
    }

    public function getSettingsIntroduction()
    {
        return $this->getI18n()->__('Specify your Github login details here to enable github integration with your account');
    }

    public function getSettings()
    {
        return [
            'github_token' => [
                'type' => 'text',
                'name' => $this->getI18n()->__('Github token'),
                'description' => $this->getI18n()->__('This is required to access private repositories and integrate Pachno with Github')
            ]
        ];
    }

}
