<?php

/**
 * @var \pachno\core\entities\User $pachno_user
 * @var \pachno\core\modules\livelink\Livelink $module
 */

?>
<form accept-charset="<?= \pachno\core\framework\Context::getI18n()->getCharset(); ?>" action="<?= make_url('configure_livelink_connector', ['connector' => 'github']); ?>" method="post" id="livelink_<?= $module->getName(); ?>_connector_form">
    <div class="backdrop_box large" id="project_config_popup_main_container">
        <div class="backdrop_detail_header">
            <span><?= __('Connect with %github', ['%github' => '&nbsp;' . fa_image_tag('github', ['class' => 'icon'], 'fab') . '<span>Github</span>']); ?></span>
            <a class="closer" href="javascript:void(0);"><?= fa_image_tag('times'); ?></a>
        </div>
        <div id="backdrop_detail_content" class="backdrop_detail_content">
            <div class="form-container">
                <div class="form">
                    <div class="form-row">
                        <div class="helper-text">
                            <span><?= __('To link with GitHub projects, you need a personal access token for Pachno. Create a new access token from %github_settings_personal_tokens, and paste the token in the input field below.', ['%github_settings_personal_tokens' => link_tag('https://github.com/settings/tokens', fa_image_tag('github', ['class' => 'icon'], 'fab') . '&nbsp;Github Developer settings &raquo; Personal access tokens', ['target' => '_blank'])]); ?></span>
                        </div>
                    </div>
                    <div class="form-row">
                        <label for="<?= $module->getName(); ?>_github_token">* <?= __('Github token'); ?></label>
                        <input type="text" name="github_token" id="<?= $module->getName(); ?>_github_token" value="" autocomplete="disabled">
                    </div>
                    <div class="form-row">
                        <div class="message-box type-info">
                            <?= fa_image_tag('key', ['class' => 'icon']); ?>
                            <span class="message">
                                <?= __('Make sure the personal access token has atleast the following permissions (scopes) set: %list', ['%list' => '']); ?>
                                <ul>
                                    <li class="command_box">repo:status</li>
                                    <li class="command_box">public_repo</li>
                                    <li class="command_box">write:repo_hook</li>
                                    <li class="command_box">read:repo_hook</li>
                                    <li class="command_box">read:user</li>
                                    <li class="command_box">user:email</li>
                                </ul>
                            </span>
                        </div>
                    </div>
                    <div class="form-row submit-container">
                        <button type="submit" class="button primary" id="livelink_<?= $module->getName(); ?>_connector_form_button">
                            <span><?= __('Save access token'); ?></span>
                            <span class="indicator"><?= fa_image_tag('spinner', ['class' => 'fa-spin']); ?></span>
                        </button>
                    </div>
                </div>
            </div>
        </div>
    </div>
</form>
<script>
    Pachno.on(Pachno.EVENTS.fetch.updated, () => {
        const form_id        = 'livelink_<?= $module->getName(); ?>_connector_form',
            $form          = $('#' + form_id);

        const submitConnectorForm = function(e) {
            const $indicator     = $('#' + form_id + '_indicator'),
                $submit_button = $('#' + form_id + '_button'),
                url            = $form.attr("action");

            $indicator.show();
            e.preventDefault();

            const submitStep = function () {
                return new Promise(function (resolve, reject) {
                    $.ajax({
                        type: 'POST',
                        data: $form.serialize(),
                        url: url,
                        success: resolve,
                        error: function (details) {
                            $indicator.hide();
                            $submit_button.attr('disabled', false);
                            reject(details);
                        }
                    });
                });
            };

            submitStep()
                .then(function (result) {
                    $('#livelink-github-configuration').addClass('connected');
                    $indicator.hide();
                    Pachno.UI.Backdrop.reset();
                }, function (details) {
                    Pachno.UI.Message.error(details.responseJSON.error);
                });
        };

        $form.off('submit');
        $form.submit(submitConnectorForm);
    });
</script>
