<?php

    namespace pachno\modules\livelink_github\controllers;

    use pachno\core\entities\Project;
    use pachno\core\entities\tables\Projects;
    use pachno\core\framework,
        Github\Client as GithubClient,
        Github\Exception\RuntimeException as GithubException,
        pachno\core\modules\livelink\Livelink,
        pachno\core\modules\livelink\ConnectorProvider;
    use pachno\modules\livelink_github\Livelink_github;

    /**
     * Main controller for the livelink module
     */
    class Main extends framework\Action
    {

        /**
         * @return Livelink_github
         */
        protected function getModule()
        {
            return framework\Context::getModule('livelink_github');
        }

        /**
         * @Route(name="configure_project_settings", url="/livelink_github/:project_id/project_settings")
         * @Parameters(config_module="core", section=15)
         *
         * @param framework\Request $request
         * @return bool
         */
        public function runConfigureProjectSettings(framework\Request $request)
        {
            try {
                if (isset($request['setup-step'])) {
                    switch ($request['setup-step']) {
                        case 1:
                            $url = str_replace(['git@github.com:', 'https://github.com/'], ['', ''], $request['repository_url']);
                            $pieces = parse_url($url);
                            $pieces = explode('/', $pieces['path']);
                            if (count($pieces) == 2) {
                                list($repository_user, $repository_name) = $pieces;
                                if (substr($repository_name, -4) == '.git') {
                                    $repository_name = substr($repository_name, 0, -4);
                                }
                            } else {
                                $this->getResponse()->setHttpStatus(400);
                                return $this->renderJSON(['error' => $this->getI18n()->__("Sorry, that did not make sense")]);
                            }

                            $client = $this->getModule()->getConnector()->getGithubClient();
                            $repository = $client->api('repo')->show($repository_user, $repository_name);

                            break;
                        case 2:
                            if ($request['project_id']) {
                                $project = Projects::getTable()->selectById($request['project_id']);
                                if (!$project instanceof Project) {
                                    throw new \Exception('Invalid project id');
                                }

                                Livelink::getModule()->saveProjectLiveLinkSettings($project, $request);
                            }

                            break;
                    }
                }
            } catch (GithubException $e) {
                if ($e->getCode() == 404) {
                    $this->getResponse()->setHttpStatus(400);
                    return $this->renderJSON(['error' => $this->getI18n()->__("That repository does not exist")]);
                } else {
                    $this->getResponse()->setHttpStatus(400);
                    return $this->renderJSON(['error' => $this->getI18n()->__("Woops, there was an error trying to connect to Github: " . $e->getMessage())]);
                }
            } catch (\Exception $e) {
                $this->getResponse()->setHttpStatus(400);
                return $this->renderJSON(['error' => $this->getI18n()->__("Woops, there was an error trying to connect to Github: " . $e->getMessage())]);
            }

            return $this->renderJSON(['connected' => true]);
        }

    }

